Enum mysqlclient_sys::enum_mysql_stmt_state
[−]
[src]
#[repr(u32)]pub enum enum_mysql_stmt_state { MYSQL_STMT_INIT_DONE, MYSQL_STMT_PREPARE_DONE, MYSQL_STMT_EXECUTE_DONE, MYSQL_STMT_FETCH_DONE, }
Variants
MYSQL_STMT_INIT_DONEMYSQL_STMT_PREPARE_DONEMYSQL_STMT_EXECUTE_DONEMYSQL_STMT_FETCH_DONETrait Implementations
impl Debug for enum_mysql_stmt_state[src]
impl Copy for enum_mysql_stmt_state[src]
impl Clone for enum_mysql_stmt_state[src]
fn clone(&self) -> enum_mysql_stmt_state
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for enum_mysql_stmt_state[src]
fn eq(&self, __arg_0: &enum_mysql_stmt_state) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for enum_mysql_stmt_state[src]
impl Hash for enum_mysql_stmt_state[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.