Enum mysqlclient_sys::enum_mysql_timestamp_type
[−]
[src]
#[repr(i32)]pub enum enum_mysql_timestamp_type { MYSQL_TIMESTAMP_NONE, MYSQL_TIMESTAMP_ERROR, MYSQL_TIMESTAMP_DATE, MYSQL_TIMESTAMP_DATETIME, MYSQL_TIMESTAMP_TIME, }
Variants
MYSQL_TIMESTAMP_NONEMYSQL_TIMESTAMP_ERRORMYSQL_TIMESTAMP_DATEMYSQL_TIMESTAMP_DATETIMEMYSQL_TIMESTAMP_TIMETrait Implementations
impl Debug for enum_mysql_timestamp_type[src]
impl Copy for enum_mysql_timestamp_type[src]
impl Clone for enum_mysql_timestamp_type[src]
fn clone(&self) -> enum_mysql_timestamp_type
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for enum_mysql_timestamp_type[src]
fn eq(&self, __arg_0: &enum_mysql_timestamp_type) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for enum_mysql_timestamp_type[src]
impl Hash for enum_mysql_timestamp_type[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.