Enum mysqlclient_sys::enum_stmt_attr_type
[−]
[src]
#[repr(u32)]pub enum enum_stmt_attr_type { STMT_ATTR_UPDATE_MAX_LENGTH, STMT_ATTR_CURSOR_TYPE, STMT_ATTR_PREFETCH_ROWS, }
Variants
STMT_ATTR_UPDATE_MAX_LENGTHSTMT_ATTR_CURSOR_TYPESTMT_ATTR_PREFETCH_ROWSTrait Implementations
impl Debug for enum_stmt_attr_type[src]
impl Copy for enum_stmt_attr_type[src]
impl Clone for enum_stmt_attr_type[src]
fn clone(&self) -> enum_stmt_attr_type
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for enum_stmt_attr_type[src]
fn eq(&self, __arg_0: &enum_stmt_attr_type) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for enum_stmt_attr_type[src]
impl Hash for enum_stmt_attr_type[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.