Enum mysqlclient_sys::mysql_enum_shutdown_level
[−]
[src]
#[repr(u32)]pub enum mysql_enum_shutdown_level { SHUTDOWN_DEFAULT, SHUTDOWN_WAIT_CONNECTIONS, SHUTDOWN_WAIT_TRANSACTIONS, SHUTDOWN_WAIT_UPDATES, SHUTDOWN_WAIT_ALL_BUFFERS, SHUTDOWN_WAIT_CRITICAL_BUFFERS, KILL_QUERY, KILL_CONNECTION, }
Variants
SHUTDOWN_DEFAULTSHUTDOWN_WAIT_CONNECTIONSSHUTDOWN_WAIT_TRANSACTIONSSHUTDOWN_WAIT_UPDATESSHUTDOWN_WAIT_ALL_BUFFERSSHUTDOWN_WAIT_CRITICAL_BUFFERSKILL_QUERYKILL_CONNECTIONTrait Implementations
impl Debug for mysql_enum_shutdown_level[src]
impl Copy for mysql_enum_shutdown_level[src]
impl Clone for mysql_enum_shutdown_level[src]
fn clone(&self) -> mysql_enum_shutdown_level
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for mysql_enum_shutdown_level[src]
fn eq(&self, __arg_0: &mysql_enum_shutdown_level) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for mysql_enum_shutdown_level[src]
impl Hash for mysql_enum_shutdown_level[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.